#
# spec file for package xfce4-diskperf-plugin
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define panel_version 4.12.0
%define plugin diskperf
%bcond_with git
Name:           xfce4-%{plugin}-plugin
Version:        2.6.2
Release:        lp152.1.1
Summary:        Disk Performance Plugin for the Xfce Panel
License:        GPL-2.0-or-later
Group:          System/GUI/XFCE
URL:            http://goodies.xfce.org/projects/panel-plugins/xfce4-diskperf-plugin
Source0:        http://archive.xfce.org/src/panel-plugins/%{name}/2.6/%{name}-%{version}.tar.bz2
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libxfce4panel-2.0) >= %{panel_version}
BuildRequires:  pkgconfig(libxfce4ui-2) >= %{panel_version}
%if %{with git}
BuildRequires:  xfce4-dev-tools
%endif
Requires:       xfce4-panel >= %{panel_version}
Recommends:     %{name}-lang = %{version}
# package was renamed in 2019 after Leap 15.1
Provides:       xfce4-panel-plugin-%{plugin} = %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin} < %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin}-debuginfo

%description
The DiskPerf plugin displays the disk/partition performance as trasferred data
per second.

%package lang
Summary:        Translations for package %{name}
Group:          System/Localization
Requires:       %{name} = %{version}
Supplements:    %{name}
Provides:       %{name}-lang-all = %{version}
# package was renamed in 2019 after Leap 15.1
Obsoletes:      xfce4-panel-plugin-%{plugin}-lang < %{version}-%{release}
Provides:       xfce4-panel-plugin-%{plugin}-lang = %{version}-%{release}
BuildArch:      noarch

%description lang
Provides translations for the "%{name}" package.

%prep
%autosetup

%build
%if %{with git}
NOCONFIGURE=1 ./autogen.sh
%configure \
  --enable-maintainer-mode \
  --disable-static
%else
%configure --disable-static
%endif
%make_build

%install
%make_install

find %{buildroot} -type f -name "*.la" -delete -print
rm -rf %{buildroot}%{_datadir}/locale/{ast,kk,tl_PH,ur_PK}

%find_lang %{name} %{name}.lang %{?no_lang_C}

%fdupes %{buildroot}%{_datadir}

%files
%doc AUTHORS NEWS README
%license COPYING
%{_libdir}/xfce4/panel/plugins/libdiskperf.so
%{_datadir}/xfce4/panel/plugins/diskperf.desktop

%files lang -f %{name}.lang

%changelog
* Fri Aug 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed sources in spec file
* Tue Aug 13 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 2.6.2
  * Translation updates
- Dropped obsolete patch missing_sysmacros.patch (fixed upstream)
* Tue Jul 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Package renamed to follow upstream name xfce4-foo-plugin
- Use lang subpackage for manual edits instead of %%lang_package macro
- Cleaned up spec file
- Added bcond for git master builds
- Only add NEWS and omit Changelog
* Sun Feb 17 2019 Maurizio Galli <maurizio.galli@gmail.com>
-  Added patch missing_sysmacros.patch
  sys/sysmacros.h required for glibc-2.25+ (bxo#13940) and (boo#1125650)
* Wed Apr 19 2017 seife+obs@b1-systems.com
- update to version 2.6.1 (2017-02-25)
  * stop always showing activity (bxo#12942)
  * fix sizing issues and GtkCssProvider lifecycle
  * fix linux for devices with major > 255 (bxo#13281)
* Sun Nov 27 2016 seife+obs@b1-systems.com
- update to version 2.6.0
  - port to gtk+3/libxfce4ui-2/libxfce4panel-2.0
* Tue Mar  3 2015 gber@opensuse.org
- update to version 2.5.5
  - use the new GtkTooltip API
  - fix a memory leak in the FreeBSD codepath (bxo#11153)
  - add support for FreeBSD (bxo#10350)
  - updated translations
* Sun Jul  1 2012 gber@opensuse.org
- update to version 2.5.4
  - better compliance with panel plugin HIG
  - use double values for progress bars
  - facilitate bringing up the configuration dialog
  - fix transparency
* Mon May 14 2012 gber@opensuse.org
- update to version 2.5.3
  - use newer tooltip API
  - make tooltip strings translatable and MB->MiB string updates
  - always update progress bars even if stats are unavailable
  - improve multirow panel support
* Sun Apr 29 2012 gber@opensuse.org
- update to version 2.5.2
  - gracefully handle device that are not present and show
    statistics only when the device is plugged
* Fri Apr 20 2012 gber@opensuse.org
- added documentation files
* Tue Apr 17 2012 gber@opensuse.org
- corrected source URL
* Sat Apr 14 2012 gber@opensuse.org
- update to version 2.5.1
  - translation updates
* Tue Apr 10 2012 gber@opensuse.org
- update to version 2.5.0
  - build the plugin as a module, loadable by Xfce4's panel wrapper
  - use an icon name compliant to the spec
* Tue Apr  3 2012 gber@opensuse.org
- update to version 2.4.0
  - port to libxfce4ui
  - Port to panel 4.9
  - Fix translations
  - explicitely link with libm
- drop obsolete xfce4-diskperf-plugin-fix-libm-underlinking.patch
  and xfce4-panel-plugin-diskperf-fix-transparency-colors.patch
- specfile cleanup
- correct dependencies
* Mon Sep 19 2011 gber@opensuse.org
- removed unrelated autoconf from the underlinking patch which
  broke the build on older releases
- added xfce4-panel-plugin-diskperf-fix-transparency-colors.patch
  which fixes transparency and bar colors (backported from upstream
  git)
* Sun Sep 18 2011 crrodriguez@opensuse.org
- Link with libm as well.
* Wed Mar  9 2011 gber@opensuse.org
- new package (split off from xfce4-panel-plugins)
